Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(71)

Unified Diff: media/base/pipeline.h

Issue 2718483003: Use base::Optional for selected video track. (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/mock_filters.h ('k') | media/base/pipeline_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/pipeline.h
diff --git a/media/base/pipeline.h b/media/base/pipeline.h
index cf3c69ee136abeeec3b51de73087573575b26686..c85fb90b65675f8b3acac62ab6047bf9b391fc8e 100644
--- a/media/base/pipeline.h
+++ b/media/base/pipeline.h
@@ -78,14 +78,14 @@ class MEDIA_EXPORT Pipeline {
Client* client,
const PipelineStatusCB& seek_cb) = 0;
// |enabledTrackIds| contains track ids of enabled audio tracks.
virtual void OnEnabledAudioTracksChanged(
- const std::vector<MediaTrack::Id>& enabledTrackIds) = 0;
+ const std::vector<MediaTrack::Id>& enabled_track_ids) = 0;
- // |trackId| either empty, which means no video track is selected, or contain
- // one element - the selected video track id.
+ // |selected_track_id| is either empty, which means no video track is
+ // selected, or contains the selected video track id.
virtual void OnSelectedVideoTrackChanged(
- const std::vector<MediaTrack::Id>& selectedTrackId) = 0;
+ base::Optional<MediaTrack::Id> selected_track_id) = 0;
// Stops the pipeline. This is a blocking function.
// If the pipeline is started, it must be stopped before destroying it.
« no previous file with comments | « media/base/mock_filters.h ('k') | media/base/pipeline_impl.h » ('j') | no next file with comments »
@@ -78,14 +78,14 @@ class MEDIA_EXPORT Pipeline {
Client* client,
const PipelineStatusCB& seek_cb) = 0;
- // |enabledTrackIds| contains track ids of enabled audio tracks.
+ // |enabled_track_ids| contains track ids of enabled audio tracks.
virtual void OnEnabledAudioTracksChanged(

Powered by Google App Engine
This is Rietveld 408576698